package com.yifu.cloud.plus.v1.yifu.insurances.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yifu.cloud.plus.v1.yifu.common.core.util.R;
import com.yifu.cloud.plus.v1.yifu.common.core.vo.YifuUser;
import com.yifu.cloud.plus.v1.yifu.common.dapr.util.MenuUtil;
import com.yifu.cloud.plus.v1.yifu.common.log.annotation.SysLog;
import com.yifu.cloud.plus.v1.yifu.common.security.util.SecurityUtils;
import com.yifu.cloud.plus.v1.yifu.insurances.entity.TInsuranceUnpurchaseApply;
import com.yifu.cloud.plus.v1.yifu.insurances.service.insurance.TInsuranceUnpurchaseApplyService;
import com.yifu.cloud.plus.v1.yifu.insurances.vo.TInsuranceUnpurchaseApplySearchVo;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;


/**
 * 含风险项目不购买申请表
 *
 * @author huych
 * @date 2025-01-10 11:24:38
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("/tinsuranceunpurchaseapply")
@Tag(name = "含风险项目不购买申请表管理")
public class TInsuranceUnpurchaseApplyController {

	private final TInsuranceUnpurchaseApplyService tInsuranceUnpurchaseApplyService;

	private final MenuUtil menuUtil;

	/**
	 * 简单分页查询
	 *
	 * @param page  分页对象
	 * @param searchVo 含风险项目不购买申请表
	 * @return
	 */
	@Operation(description = "简单分页查询")
	@GetMapping("/page")
	public R<IPage<TInsuranceUnpurchaseApply>> getTInsuranceUnpurchaseApplyPage(Page<TInsuranceUnpurchaseApply> page, TInsuranceUnpurchaseApplySearchVo searchVo) {
		YifuUser user = SecurityUtils.getUser();
		menuUtil.setAuthSql(user, searchVo);
		return new R<>(tInsuranceUnpurchaseApplyService.getTInsuranceUnpurchaseApplyPage(page, searchVo));
	}

	/**
	 * 通过id查询含风险项目不购买申请表
	 *
	 * @param id id
	 * @return R
	 */
	@Operation(summary = "通过id查询", description = "通过id查询")
	@GetMapping("/{id}")
	public R<TInsuranceUnpurchaseApply> getById(@PathVariable("id") String id) {
		return R.ok(tInsuranceUnpurchaseApplyService.getById(id));
	}

	/**
	 * 新增含风险项目不购买申请表
	 *
	 * @param tInsuranceUnpurchaseApply 含风险项目不购买申请表
	 * @return R
	 */
	@Operation(summary = "新增含风险项目不购买申请表", description = "新增含风险项目不购买申请表")
	@SysLog("新增含风险项目不购买申请表")
	@PostMapping("/add")
	public R save(@RequestBody TInsuranceUnpurchaseApply tInsuranceUnpurchaseApply) {
		return new R<>(tInsuranceUnpurchaseApplyService.save(tInsuranceUnpurchaseApply));
	}

	/**
	 * 修改含风险项目不购买申请表
	 *
	 * @param tInsuranceUnpurchaseApply 含风险项目不购买申请表
	 * @return R
	 */
	@Operation(summary = "修改含风险项目不购买申请表", description = "修改含风险项目不购买申请表：hasPermission('insurances_tinsuranceunpurchaseapply_edit')")
	@SysLog("修改含风险项目不购买申请表")
	@PutMapping
	@PreAuthorize("@pms.hasPermission('insurances_tinsuranceunpurchaseapply_edit')")
	public R<Boolean> updateById(@RequestBody TInsuranceUnpurchaseApply tInsuranceUnpurchaseApply) {
		return R.ok(tInsuranceUnpurchaseApplyService.updateById(tInsuranceUnpurchaseApply));
	}

	/**
	 * 通过id删除含风险项目不购买申请表
	 *
	 * @param id id
	 * @return R
	 */
	@Operation(summary = "通过id删除含风险项目不购买申请表", description = "通过id删除含风险项目不购买申请表：hasPermission('insurances_tinsuranceunpurchaseapply_del')")
	@SysLog("通过id删除含风险项目不购买申请表")
	@PostMapping("/id")
	@PreAuthorize("@pms.hasPermission('insurances_tinsuranceunpurchaseapply_del')")
	public R removeById(@RequestParam String id) {
		return tInsuranceUnpurchaseApplyService.deleteById(id);
	}

	/**
	 * 含风险项目不购买申请表 批量导出
	 *
	 * @author huych
	 * @date 2025-01-10 11:24:38
	 **/
	@Operation(description = "导出含风险项目不购买申请表")
	@PostMapping("/export")
	public void export(HttpServletResponse response, @RequestBody TInsuranceUnpurchaseApplySearchVo searchVo) {
		YifuUser user = SecurityUtils.getUser();
		menuUtil.setAuthSql(user, searchVo);
		tInsuranceUnpurchaseApplyService.listExport(response, searchVo);
	}
}
