package com.yifu.cloud.plus.v1.yifu.insurances.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yifu.cloud.plus.v1.yifu.common.core.util.R;
import com.yifu.cloud.plus.v1.yifu.common.core.vo.YifuUser;
import com.yifu.cloud.plus.v1.yifu.common.dapr.util.MenuUtil;
import com.yifu.cloud.plus.v1.yifu.common.log.annotation.SysLog;
import com.yifu.cloud.plus.v1.yifu.common.security.util.SecurityUtils;
import com.yifu.cloud.plus.v1.yifu.insurances.entity.TInsuranceUnpurchasePerson;
import com.yifu.cloud.plus.v1.yifu.insurances.service.insurance.TInsuranceUnpurchasePersonService;
import com.yifu.cloud.plus.v1.yifu.insurances.vo.TInsuranceUnpurchasePersonSearchVo;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;


/**
 * 含风险项目不购买申请明细表
 *
 * @author huych
 * @date 2025-01-10 11:23:21
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("/tinsuranceunpurchaseperson" )
@Tag(name = "含风险项目不购买申请明细表管理")
public class TInsuranceUnpurchasePersonController {

    private final TInsuranceUnpurchasePersonService tInsuranceUnpurchasePersonService;

	private final MenuUtil menuUtil;
    
    /**
     * 简单分页查询
     * @param page 分页对象
     * @param searchVo 含风险项目不购买申请明细表
     * @return
     */
    @Operation(description = "简单分页查询")
    @GetMapping("/page")
    public R<IPage<TInsuranceUnpurchasePerson>> getTInsuranceUnpurchasePersonPage(Page<TInsuranceUnpurchasePerson> page, TInsuranceUnpurchasePersonSearchVo searchVo) {
		YifuUser user = SecurityUtils.getUser();
		menuUtil.setAuthSql(user, searchVo);
		return new R<>(tInsuranceUnpurchasePersonService.getTInsuranceUnpurchasePersonPage(page,searchVo));
    }

    /**
     * 通过id查询含风险项目不购买申请明细表
     * @param id id
     * @return R
     */
    @Operation(summary = "通过id查询", description = "通过id查询")
    @GetMapping("/{id}")
    public R<TInsuranceUnpurchasePerson> getById(@PathVariable("id" ) String id) {
        return R.ok(tInsuranceUnpurchasePersonService.getById(id));
    }

    /**
     * 新增含风险项目不购买申请明细表
     * @param tInsuranceUnpurchasePerson 含风险项目不购买申请明细表
     * @return R
     */
    @Operation(summary = "新增含风险项目不购买申请明细表", description = "新增含风险项目不购买申请明细表")
    @SysLog("新增含风险项目不购买申请明细表")
    @PostMapping
    public R<Boolean> save(@RequestBody TInsuranceUnpurchasePerson tInsuranceUnpurchasePerson) {
        return R.ok(tInsuranceUnpurchasePersonService.save(tInsuranceUnpurchasePerson));
    }

    /**
     * 修改含风险项目不购买申请明细表
     * @param tInsuranceUnpurchasePerson 含风险项目不购买申请明细表
     * @return R
     */
    @Operation(summary = "修改含风险项目不购买申请明细表", description = "修改含风险项目不购买申请明细表")
    @SysLog("修改含风险项目不购买申请明细表")
    @PutMapping
    public R<Boolean> updateById(@RequestBody TInsuranceUnpurchasePerson tInsuranceUnpurchasePerson) {
        return R.ok(tInsuranceUnpurchasePersonService.updateById(tInsuranceUnpurchasePerson));
    }

    /**
     * 通过id删除含风险项目不购买申请明细表
     * @param id id
     * @return R
     */
    @Operation(summary = "通过id删除含风险项目不购买申请明细表", description = "通过id删除含风险项目不购买申请明细表：hasPermission('insurances_tinsuranceunpurchaseperson_del')")
    @SysLog("通过id删除含风险项目不购买申请明细表" )
    @DeleteMapping("/{id}" )
    @PreAuthorize("@pms.hasPermission('insurances_tinsuranceunpurchaseperson_del')" )
    public R<Boolean> removeById(@PathVariable String id) {
        return R.ok(tInsuranceUnpurchasePersonService.removeById(id));
    }

    /**
     * 含风险项目不购买申请明细表 批量导出
     * @author huych
     * @date 2025-01-10 11:23:21
     **/
    @Operation(description = "导出含风险项目不购买申请明细表 hasPermission('insurances_tinsuranceunpurchaseperson-export')")
    @PostMapping("/export")
    @PreAuthorize("@pms.hasPermission('insurances_tinsuranceunpurchaseperson-export')")
    public void export(HttpServletResponse response, @RequestBody TInsuranceUnpurchasePersonSearchVo searchVo) {
		YifuUser user = SecurityUtils.getUser();
		menuUtil.setAuthSql(user, searchVo);
		tInsuranceUnpurchasePersonService.listExport(response,searchVo);
    }
}
